import { ApiRequest } from '../ApiRequest';
/**
 * A method that allows you to create and delete Custom fieldss one by one or
 * one by one. The user will not be able to change their values ​​from the
 * interface, but will be able to filter on them and view them. Creating and
 * deleting a field is also possible from the interface.
 */
export declare class CustomField {
    apiRequest: ApiRequest;
    private url;
    constructor(apiRequest: ApiRequest);
    add(params: Schema$CustomFieldParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
    /**
     * @param params
     */
    update(params: Schema$CustomFieldParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
    delete(params: Schema$CustomFieldDeleteParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
}
export interface Schema$CustomFieldParams {
    /** field name  */
    name: string;
    /** Field type  */
    field_type?: number;
    /** Entity type  */
    element_type?: number;
    /**
     * The unique identifier of the service, which will be available for deleting
     * and changing the field
     */
    origin: string;
    is_editable?: boolean;
    /**
     * An array of values ​​for a list or multisession. Values ​​are
     * indicated by string variables, separated by commas.
     */
    enums?: string[];
    /**
     * The unique identifier of the entry in the client program (parameteral
     * parameter). Information about request_id is not saved anywhere.
     */
    request_id?: number;
    /** Required field  This property is only applicable to list fields    */
    is_required?: boolean;
    is_deletable?: boolean;
    /**
     * Field visibility in the interface. This property is only applicable to
     * list fields
     */
    is_visible?: boolean;
}
export interface Schema$CustomFieldDeleteParams {
    /** A unique identifier for the field that is to be deleted */
    id: number;
    /**
     * The unique identifier of the service, which will be available for deleting
     * and changing the field
     */
    origin: string;
}
export declare enum FieldType {
    TEXT = 1,
    NUMERIC = 2,
    CHECKBOX = 3,
    SELECT = 4,
    MULTISELECT = 5,
    DATE = 6,
    URL = 7,
    MULTITEXT = 8
}
