import { ApiRequest } from '../ApiRequest';
/**
 * Stages of customer is a sequence of steps that a potential customer
 * (customer) is taking on the pipeline of customers before buying. In amoCRM,
 * you can create your own periods to track the progress of the customer. The
 * customer pipeline can contain 10 periods "before purchase" (including
 * "recently bought", "bought today" and "not bought"). The administrator of the
 * account can configure the periods on the Digital Pipeline page. These methods
 * are only available to the *account administrator*
 *
 * @link https://www.amocrm.com/developers/content/api/customers
 */
export declare class CustomersPeriods {
    apiRequest: ApiRequest;
    private url;
    constructor(apiRequest: ApiRequest);
    /**
     * Method for obtaining a list of periods. The GET request is sent without any
     * additional parameters.
     */
    list(): Promise<import("gaxios").GaxiosResponse<any>>;
    /**
     * Add, delete, and update customer stages
     * The method allows you to change data by period. When changing, you need to
     * transfer a complete list of periods, including those already existing. When
     * deleting a period, you need to exclude it from the query.
     *
     * @param params
     */
    update(params: Schema$CustomersPeriodsParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
}
export declare type colorPeriods = '#fffeb2' | '#fffd7f' | '#fff000' | '#ffeab2' | '#ffdc7f' | '#ffce5a' | '#ffdbdb' | '#ffc8c8' | '#ff8f92' | '#d6eaff' | '#c1e0ff' | '#98cbff' | '#ebffb1' | '#deff81' | '#87f2c0' | '#f9deff' | '#f3beff' | '#ccc8f9' | '#eb93ff' | '#f2f3f4' | '#e6e8ea';
export interface Schema$CustomersPeriodsParams {
    /**
     * Number of days in the period. IMPORTANT!!! This parameter determines the
     * fixed length of the period and does not coincide with the number of days
     * "before purchase". The number of days before the purchase is calculated by
     * adding this parameter for all periods from the "purchase day" to the right
     * to the left. For example: to get "90, 30 and 10 days before the purchase,"
     * you need to create 3 periods of 10, 20 and 60 days: 1) 10 + 20 = 30 days
     * before the purchase. 2) 30 + 60 = 90 days before purchase.
     */
    period?: number;
    /**
     * The unique identifier of the pipeline. (If the id is not passed, a new
     * period will be created).
     */
    id?: number;
    /** Period color */
    color: string;
    name: string;
    /**
     * The period ordinal of the period when displayed (Periods are displayed to
     * the right of the left starting from the "purchase day").
     */
    sort?: number;
}
