"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CustomersPeriods = void 0;
/**
 * Stages of customer is a sequence of steps that a potential customer
 * (customer) is taking on the pipeline of customers before buying. In amoCRM,
 * you can create your own periods to track the progress of the customer. The
 * customer pipeline can contain 10 periods "before purchase" (including
 * "recently bought", "bought today" and "not bought"). The administrator of the
 * account can configure the periods on the Digital Pipeline page. These methods
 * are only available to the *account administrator*
 *
 * @link https://www.amocrm.com/developers/content/api/customers
 */
class CustomersPeriods {
    constructor(apiRequest) {
        this.apiRequest = apiRequest;
        this.url = '/api/v2/customers_periods';
    }
    /**
     * Method for obtaining a list of periods. The GET request is sent without any
     * additional parameters.
     */
    list() {
        return this.apiRequest.get(this.url);
    }
    /**
     * Add, delete, and update customer stages
     * The method allows you to change data by period. When changing, you need to
     * transfer a complete list of periods, including those already existing. When
     * deleting a period, you need to exclude it from the query.
     *
     * @param params
     */
    update(params) {
        const options = { data: { update: params } };
        return this.apiRequest.post(this.url, options);
    }
}
exports.CustomersPeriods = CustomersPeriods;
//# sourceMappingURL=CustomersPeriods.js.map