import { ApiRequest } from '../ApiRequest';
import { Schema$CustomField } from './Account';
import { Schema$EntityParams } from './Entity';
import { Schema$GetListParams } from './ListEntity';
/**
 * The method allows you to add leads one by one or in bulk, as well as update
 * data on existing leads.
 *
 * @link https://www.amocrm.com/developers/content/api/leads
 */
export declare class Lead {
    apiRequest: ApiRequest;
    private url;
    constructor(apiRequest: ApiRequest);
    list(params: Schema$GetListParams, modified?: string): Promise<import("gaxios").GaxiosResponse<any>>;
    add(params: Schema$LeadAddParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
    update(params: Schema$LeadUpdateParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
}
interface Schema$LeadParams {
    /** The name of the lead  */
    name?: string;
    /**  Deal budget */
    sale?: number;
    /**
     * Status of the lead (id of the sales phase, see Pipelines and stages of
     * sales) To transfer the lead to another pipeline, you need to set its status
     * from the desired pipeline
     */
    status_id?: number;
    /**
     * ID of the pipeline. It is indicated if id 142 or 143 statuses are
     * selected, because These statuses are not unique and are mandatory for all
     * digital pipelines.
     */
    pipeline_id?: number;
    /**
     * The unique identifier for the contact to contact the lead. You can pass
     * multiple id, listing them in an array separated by commas.
     */
    contacts_id?: number | number[];
    /** The unique identifier of the company to contact the lead  */
    company_id?: number;
    /** Inside this array is the contents of each filled additional field */
    custom_fields?: Schema$CustomField[];
}
export interface Schema$LeadAddParams extends Schema$LeadParams, Schema$EntityParams {
    /** The name of the lead  */
    name: string;
}
export interface Schema$LeadUpdateParams extends Schema$LeadParams, Schema$EntityParams {
    id: number;
    updated_at: number;
    unlink?: Schema$LeadUnlinkEntity;
}
declare type Schema$LeadUnlinkEntity = {
    company_id?: number;
    contacts_id?: number[] | string[];
};
export {};
