"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NoteType = exports.Note = void 0;
/**
 * Events provide the ability to add additional structured or unstructured
 * information to an entity element. Events can be system calls (calls, SMS
 * messages, etc.) created by the user (notes, files). The events in the cards
 * are displayed alongside the to-dos, because do not have a responsible one and
 * are not attached to the date. Often events are used by widgets to add
 * additional information to a lead or contact, when it is not very convenient
 * to use additional fields. Events are very convenient to use as a log, because
 * they are always displayed in chronological order in the tape, and if your
 * information is tied to a date (chronology), then it is desirable to use
 * events.
 *
 * The method allows you to add new or update existing events.
 *
 * @link https://www.amocrm.com/developers/content/api/notes
 */
class Note {
    constructor(apiRequest) {
        this.apiRequest = apiRequest;
        this.url = '/api/v2/notes';
    }
    /**
     * Method for obtaining a list of notes with the possibility of filtering and
     * pagination. Restriction on data returned on one page (offset) - 500
     * entries.
     *
     * @param params
     * @param modified
     */
    list(params, modified) {
        const options = { params: { ...params } };
        if (modified) {
            options['headers'] = { 'IF-MODIFIED-SINCE': modified };
        }
        return this.apiRequest.get(this.url, options);
    }
    add(params) {
        const options = { data: { add: params } };
        return this.apiRequest.post(this.url, options);
    }
    update(params) {
        const options = { data: { update: params } };
        return this.apiRequest.post(this.url, options);
    }
}
exports.Note = Note;
/**
 *  Types of events
 *
 * @link https://www.amocrm.com/developers/content/api/notes#note_types
 */
var NoteType;
(function (NoteType) {
    NoteType[NoteType["LEAD_CREATED"] = 1] = "LEAD_CREATED";
    NoteType[NoteType["CONTACT_CREATED"] = 2] = "CONTACT_CREATED";
    NoteType[NoteType["LEAD_STATUS_CHANGED"] = 3] = "LEAD_STATUS_CHANGED";
    /** Normal note  */
    NoteType[NoteType["COMMON"] = 4] = "COMMON";
    NoteType[NoteType["CALL_IN"] = 10] = "CALL_IN";
    NoteType[NoteType["CALL_OUT"] = 11] = "CALL_OUT";
    NoteType[NoteType["COMPANY_CREATED"] = 12] = "COMPANY_CREATED";
    NoteType[NoteType["TASK_RESULT"] = 13] = "TASK_RESULT";
    NoteType[NoteType["SYSTEM"] = 25] = "SYSTEM";
    NoteType[NoteType["SMS_IN"] = 102] = "SMS_IN";
    NoteType[NoteType["SMS_OUT"] = 103] = "SMS_OUT";
})(NoteType = exports.NoteType || (exports.NoteType = {}));
//# sourceMappingURL=Note.js.map