import { ApiRequest } from '../ApiRequest';
import { Schema$CustomField } from './Account';
import { EntityType, Schema$EntityParams } from './Entity';
import { Schema$GetListParams } from './ListEntity';
/**
 * The task must necessarily have a responsible and a date (number and time).
 * Also, a task can be associated with a lead or contact, but not necessarily,
 * it may not be associated with any object. The main essence of the system are
 * to-dos. You can set the result for a closed task using the notes method.
 *
 * This method allows you to add a new one or modify an existing task.
 * To set the result by task, use the notes method, setting the appropriate note
 * type.
 *
 * @link https://www.amocrm.com/developers/content/api/tasks
 */
export declare class Task {
    apiRequest: ApiRequest;
    private url;
    constructor(apiRequest: ApiRequest);
    /**
     * Method for obtaining a list of tasks with the possibility of filtering and
     * paging. Restriction on data returned on one page (offset) - 500 tasks.
     * Overdue tasks - those tasks where complete_till_at is less than the current
     * time and status - is not closed.
     *
     * @param params
     * @param modified
     */
    list(params: Schema$TaskGetListParams, modified?: string): Promise<import("gaxios").GaxiosResponse<any>>;
    add(params: Schema$TaskAddParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
    update(params: Schema$TaskUpdateParams[]): Promise<import("gaxios").GaxiosResponse<any>>;
}
interface Schema$TaskParams {
    /**
     * Unique identifier of a contact or lead (lead or contact is specified in
     * element_type)
     */
    element_id?: number;
    /**
     * The type of the element to be attached (1-contact, 2-lead, 3-company,
     * 12-customer)
     */
    element_type?: EntityType;
    /**
     * The date to which you want to complete the task. If the time is 23:59,
     * then "All day" will be displayed in the system interfaces instead of time.
     */
    complete_till_at?: number;
    /** Type of task (task types see here) */
    task_type?: TaskType | number;
    /** Task text */
    text?: string;
    /** Task completed or not */
    is_completed?: boolean;
    /**
     * Status of the Task (id of the sales phase, see Pipelines and stages of
     * sales) To transfer the Task to another pipeline, you need to set its status
     * from the desired pipeline
     */
    status_id?: number;
    /**
     * ID of the pipeline. It is indicated if id 142 or 143 statuses are
     * selected, because These statuses are not unique and are mandatory for all
     * digital pipelines.
     */
    pipeline_id?: number;
    /**
     * The unique identifier for the contact to contact the Task. You can pass
     * multiple id, listing them in an array separated by commas.
     */
    contacts_id?: number | number[];
    /** The unique identifier of the company to contact the Task  */
    company_id?: number;
    /** Inside this array is the contents of each filled additional field */
    custom_fields?: Schema$CustomField[];
}
export interface Schema$TaskAddParams extends Schema$TaskParams, Schema$EntityParams {
    /** The name of the Task  */
    name: string;
}
export interface Schema$TaskUpdateParams extends Schema$TaskParams, Schema$EntityParams {
    id: number;
    updated_at: number;
}
export interface Schema$TaskGetListParams extends Schema$GetListParams {
    /**
     * Obtaining data by the type of the specified entity (lead / contact /
     * company / customer)
     */
    type?: string;
    /** An additional search filter, according to the id elements of the entity */
    element_id?: number;
}
export declare enum TaskType {
    CALL = 1,
    MEETING = 2,
    WRITE_EMAIL = 3
}
export {};
