"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TaskType = exports.Task = void 0;
/**
 * The task must necessarily have a responsible and a date (number and time).
 * Also, a task can be associated with a lead or contact, but not necessarily,
 * it may not be associated with any object. The main essence of the system are
 * to-dos. You can set the result for a closed task using the notes method.
 *
 * This method allows you to add a new one or modify an existing task.
 * To set the result by task, use the notes method, setting the appropriate note
 * type.
 *
 * @link https://www.amocrm.com/developers/content/api/tasks
 */
class Task {
    constructor(apiRequest) {
        this.apiRequest = apiRequest;
        this.url = '/api/v2/tasks';
    }
    /**
     * Method for obtaining a list of tasks with the possibility of filtering and
     * paging. Restriction on data returned on one page (offset) - 500 tasks.
     * Overdue tasks - those tasks where complete_till_at is less than the current
     * time and status - is not closed.
     *
     * @param params
     * @param modified
     */
    list(params, modified) {
        const options = { params: { ...params } };
        if (modified) {
            options['headers'] = { 'IF-MODIFIED-SINCE': modified };
        }
        return this.apiRequest.get(this.url, options);
    }
    add(params) {
        const options = { data: { add: params } };
        return this.apiRequest.post(this.url, options);
    }
    update(params) {
        const options = { data: { update: params } };
        return this.apiRequest.post(this.url, options);
    }
}
exports.Task = Task;
var TaskType;
(function (TaskType) {
    TaskType[TaskType["CALL"] = 1] = "CALL";
    TaskType[TaskType["MEETING"] = 2] = "MEETING";
    TaskType[TaskType["WRITE_EMAIL"] = 3] = "WRITE_EMAIL";
})(TaskType = exports.TaskType || (exports.TaskType = {}));
//# sourceMappingURL=Task.js.map